@@ -1,8 +1,8 @@
 ##########################################################################################
 # Designed and developed by Tinniam V Ganesh
-# Date : 3 May 2020
+# Date : 5 Jan 2021
 # Function: rankT20Bowlers
-# This function creates a dataframe of all T20 batsmen performances and then
+# This function ranks the  bowlers
 # ranks the  batsmen
 #
 ###########################################################################################
@@ -25,9 +25,9 @@
 #'
 #' @return The ranked T20 bowlers
 #' @references
-#' \url{http://cricsheet.org/}\cr
-#' \url{https://gigadom.wordpress.com/}\cr
-#' \url{https://github.com/tvganesh/yorkrData}
+#' \url{https://cricsheet.org/}\cr
+#' \url{https://gigadom.in/}\cr
+#' \url{https://github.com/tvganesh/yorkrData/}
 #'
 #' @author
 #' Tinniam V Ganesh
@@ -49,6 +49,7 @@
 #'
 rankT20Bowlers <- function(dir='.',odir=".",minMatches=20) {
     bowlingDetails=bowler=wickets=economyRate=matches=meanWickets=meanER=totalWickets=NULL
+    wicketPlayerOut=opposition=venue=NULL
     currDir= getwd()
     teams <-c("Australia","India","Pakistan","West Indies", 'Sri Lanka',
               "England", "Bangladesh","Netherlands","Scotland", "Afghanistan",
@@ -58,67 +59,43 @@ rankT20Bowlers <- function(dir='.',odir=".",minMatches=20) {
               "United States of America","Bhutan","Maldives","Botswana","Nigeria",
               "Denmark","Germany","Jersey","Norway","Qatar","Malaysia","Vanuatu",
               "Thailand")
-
-    #teams <- c("Australia","India","Singapore","West Indies")
-    # Get all bowling details
-
-    details=df=NULL
-    teams1 <- NULL
-    for(team in teams){
-        print(team)
-        tryCatch({
-            bowling <- getTeamBowlingDetails(team,dir=dir, save=TRUE,odir=odir)
-            teams1 <- c(teams1,team)
-        },
-        error = function(e) {
-            print("No data")
-
-        }
-        )
-    }
     #Change dir
     setwd(odir)
     bowlingDF<-NULL
 
     # Compute wickets by bowler in each team
     o <- data.frame(bowler=character(0),wickets=numeric(0),economyRate=numeric(0))
-    for(team1 in teams1){
+    for(team1 in teams){
         bowlingDetails <- NULL
         val <- paste(team1,"-BowlingDetails.RData",sep="")
         print(val)
-        tryCatch({
-            load(val)
-            bowlers <- unique(bowlingDetails$bowler)
-            for (y in 1:length(bowlers)){
-                #cat("x=",x,"team",theTeams[x],"\n")
-                tryCatch(l <- getBowlerWicketDetails(team=team1,name=bowlers[y],dir="."),
-                         error = function(e) {
-                             #print("Error!")
+        tryCatch(load(val),
+                 error = function(e) {
+                     print("No data1")
+                     setNext=TRUE
+                 }
 
-                         }
 
-                )
-                if(exists("l")){
-                    l1 <- l %>% group_by(bowler,wickets,economyRate) %>%  distinct(date)
-                    l2 <-summarise(group_by(l1,bowler),matches=n(),totalWickets=sum(wickets),
-                                   meanER=mean(economyRate))
-
-                    o <-rbind(o,l2)
-                }
-
-            }
-        },
-        error = function(e) { # Error in load
-            print("No data1")
-            setNext=TRUE
-        }
         )
-
+        details <- bowlingDetails
+        bowlingDF <- rbind(bowlingDF,details)
     }
-    # Reset to currDir
+    # Compute number of matches played
+    a=bowlingDF %>% select(bowler,date) %>% unique()
+    b=summarise(group_by(a,bowler),matches=n())
+
+    # Compute wickets
+    c <- filter(bowlingDF,wicketPlayerOut != "nobody")
+    d <- select(c,bowler,wicketPlayerOut,economyRate,date,opposition,venue)
+    e <- summarise(group_by(d,bowler,date,economyRate),wickets=length(unique(wicketPlayerOut)))
+    f=summarise(group_by(e,bowler), totalWickets=sum(wickets),meanER=mean(economyRate))
+
+    # Join
+    g=merge(b,f,by="bowler",all.x = TRUE)
+    g[is.na(g)] <- 0
+    h <- filter(g,matches >= minMatches)
     setwd(currDir)
-    q <- filter(o,matches >= minMatches)
-    T20BowlersRank <- arrange(q,desc(totalWickets),desc(meanER))
+    T20BowlersRank <- arrange(h,desc(totalWickets),desc(meanER))
     T20BowlersRank <- distinct(T20BowlersRank)
     T20BowlersRank
 }
